# Acknowledgements

[igraph](https://igraph.org) includes or links to code from the following sources.


#### [bliss 0.75](https://users.aalto.fi/~tjunttil/bliss/)

Copyright (c) 2003-2021 Tommi Junttila.

License: [GNU LGPLv3][lgpl3]


#### [Cliquer 1.21](https://users.aalto.fi/~pat/cliquer.html)

Copyright (C) 2002 Sampo Niskanen, Patric Östergård.

License: [GNU GPLv2][gpl2] or later


#### [PRPACK](https://github.com/DavidKurokawa/prpack)

Copyright (C) David Kurokawa, David Gleich, Chen Greif.


#### [gengraph](https://www-complexnetworks.lip6.fr/~latapy/FV/generation.html)

Algorithm by Fabien Viger and Matthieu Latapy.

Implementation Copyright (C) Fabien Viger.

License: [GNU GPLv2][gpl2] or later


#### [Walktrap 0.2](https://www-complexnetworks.lip6.fr/~latapy/PP/walktrap.html)

Algorithm by Pascal Pons and Matthieu Latapy.

Implementation Copyright (C) 2004-2005 Pascal Pons.

License: [GNU GPLv2][gpl2] or later


#### [plfit](https://github.com/ntamas/plfit)

Copyright (C) 2010-2011 Tamás Nepusz.

License: [GNU GPLv2][gpl2] or later

#### DrL

Copyright 2007 Sandia Corporation. Under the terms of Contract
DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
certain rights in this software.

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

  * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
  * Neither the name of Sandia National Laboratories nor the names of
its contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


#### [Hierarchical Random Graphs](http://tuvalu.santafe.edu/~aaronc/hierarchy/)

Copyright (C) 2006-2008 Aaron Clauset.

License: [GNU GPLv2][gpl2] or later


#### SCGlib (Spectral Coarse Graining)

Copyright (C) 2008 David Morton de Lachapelle <david.morton@a3.epfl.ch>

License: [GNU GPLv2][gpl2] or later


#### Spinglass community detection

Copyright (C) 2004 by Joerg Reichardt.

License: [GNU GPLv2][gpl2] or later


#### [LAD version 1](http://liris.cnrs.fr/csolnon/LAD.html)

Copyright (C) Christine Solnon.

License: [CeCILL-B license](https://cecill.info/licences.en.html)


#### [LAPACK 3.5.0](http://www.netlib.org/lapack/)

Copyright (c) 1992-2011 The University of Tennessee and The University of Tennessee Research Foundation.  All rights reserved.

Copyright (c) 2000-2011 The University of California Berkeley. All rights reserved.

Copyright (c) 2006-2012 The University of Colorado Denver.  All rights reserved.

License: [New BSD license](http://www.netlib.org/lapack/LICENSE.txt)

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
  notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
  notice, this list of conditions and the following disclaimer listed
  in this license in the documentation and/or other materials
  provided with the distribution.

- Neither the name of the copyright holders nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

The copyright holders provide no reassurances that the source code
provided does not infringe any patent, copyright, or any other
intellectual property rights of third parties.  The copyright holders
disclaim any liability to any recipient for claims brought against
recipient by any third party for infringement of that parties
intellectual property rights.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


#### [f2c](http://www.netlib.org/f2c/)

Copyright 1990 - 1997 by AT&T, Lucent Technologies and Bellcore.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the names of AT&T, Bell Laboratories,
Lucent or Bellcore or any of their entities not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

AT&T, Lucent and Bellcore disclaim all warranties with regard to
this software, including all implied warranties of
merchantability and fitness.  In no event shall AT&T, Lucent or
Bellcore be liable for any special, indirect or consequential
damages or any damages whatsoever resulting from loss of use,
data or profits, whether in an action of contract, negligence or
other tortious action, arising out of or in connection with the
use or performance of this software.


#### [SuiteSparse](http://www.suitesparse.com)

 * CXSPARSE: a Concise Sparse Matrix package - Extended. Copyright (c) 2006-2017, Timothy A. Davis.

   License: [GNU LGPLv2.1][lgpl2] or later


#### [GLPK (GNU Linear Programming Kit) Version 4.45](https://www.gnu.org/software/glpk/)

Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
2009, 2010 Andrew Makhorin, Department for Applied Informatics,
Moscow Aviation Institute, Moscow, Russia. All rights reserved.
E-mail: <mao@gnu.org>.

License: [GNU GPLv3][gpl3] or later


#### [GMP (GNU Multiple Precision Arithmetic Library)](https://gmplib.org/)

Copyright (C) Free Software Foundation, Inc.

License: [GNU LGPLv3][lgpl3] or later; or [GNU GPLv2][gpl2] or later


#### [libxml2](http://xmlsoft.org/)

Copyright (C) 1998-2012 Daniel Veillard.

License: [MIT license][mit]


 [mit]:   https://opensource.org/licenses/mit-license.html
 [gpl2]:  https://www.gnu.org/licenses/gpl-2.0.html
 [lgpl2]: https://www.gnu.org/licenses/lgpl-2.1.html
 [gpl3]:  https://www.gnu.org/licenses/gpl-3.0.html
 [lgpl3]: https://www.gnu.org/licenses/lgpl-3.0.html
